#if IP5
#ifndef __SYS_IP5ADDRS_H__
#define __SYS_IP5ADDRS_H__

/**************************************************************************
 *									  *
 * 		 Copyright (C) 1990, Silicon Graphics, Inc.		  *
 *									  *
 *  These coded instructions, statements, and computer programs  contain  *
 *  unpublished  proprietary  information of Silicon Graphics, Inc., and  *
 *  are protected by Federal copyright law.  They  may  not be disclosed  *
 *  to  third  parties  or copied or duplicated in any form, in whole or  *
 *  in part, without the prior written consent of Silicon Graphics, Inc.  *
 *									  *
 **************************************************************************/
#ident "$Revision: 3.17 $"

/*
 * Definitions of physical memory usage for the IP5
 * 
 * Physical memory usage for the IP5
 * 
 * 				---------------------------------
 * 0x1fffffff			|				|
 * 				---------------------------------
 * 0x1fc00000			| prom text & read only data	|
 * 				---------------------------------
 * 				| SASH				|
 * 0x00700000			---------------------------------
 *				| IP5 MONITOR			|
 * 0x00600000			---------------------------------
 *				|				|
 * 0x0001b000			| Debug version of UNIX		|
 * 				---------------------------------
 * 0x0001b000			| IP5 Prom stack cpu 7 / UNIX	|
 * 				---------------------------------
 * 0x0001a000			| IP5 Prom stack cpu 6 / UNIX	|
 * 				---------------------------------
 * 0x00019000			| IP5 Prom stack cpu 5 / UNIX	|
 * 				---------------------------------
 * 0x00018000			| IP5 Prom stack cpu 4 / UNIX	|
 * 				---------------------------------
 * 0x00017000			| IP5 Prom stack cpu 3 / UNIX	|
 * 				---------------------------------
 * 0x00016000			| IP5 Prom stack cpu 2 / UNIX	|
 * 				---------------------------------
 * 0x00015000			| IP5 Prom stack cpu 1 / UNIX	|
 * 				---------------------------------
 * 0x00014000			| IP5 Prom stack cpu 0 / UNIX	|
 * 				---------------------------------
 * 0x00003000			| IP5 Prom bss/ UNIX		|
 * 				--------------------------------
 * 0x00001000			| GM Communication area (8k)	|
 * 				---------------------------------
 * 0x00000500			| MPCONF block			|
 * 				---------------------------------
 * 0x00000400			| restart block			|
 * 				---------------------------------
 * 0x00000080			| general exception handler	|
 * 				---------------------------------
 * 0x00000000			| utlbmiss handler		|
 * 				---------------------------------
 *
 * *********************** NOTE *************************
 * To allow two SKYWRITER pipes in a system, the 8Kbytes GM
 * communication area is now different.  The change is ugly
 * but hopefully will allow two GMs to coexist without requiring
 * modification to the CPU PROM.
 *
 * The 8Kbyte area for VGX(1 pipe), starting at address 0x1000:
 *	2Kb 	host to GM communication area.
 * 	2Kb	GM to host communication area.
 *	1Kb	area for GM powerup diagnostics.
 *	2Kb	host and GM shared area.
 *	1Kb	unused.
 * The new scheme is as follow:
 *	2Kb	host to GM communication area for pipe 0.
 * 	2Kb	GM to host communication area for pipe 0.
 *	1Kb	area for GM powerup diagnostics for pipe 0.
 *	1Kb	host and GM shared area for pipe 0.
 *	1Kb	host and GM shared area for pipe 1.
 *	1Kb	area for GM powerup diagnostics for pipe 1.
 * The 2Kb host to GM communication area and the 2Kb GM to host
 * communication area for pipe 1 are allocated by the kernel
 * at driver init time.  The physical address of this memory
 * is stored by the host at a known place in the host and GM shared area
 * for pipe 1.  When the GM of pipe 1 gets an init memory command,
 * it reads in this address and uses it for communication from then
 * on.
 */ 

/*
 * Address definitions
 * Note: When moving address map between 0 to SYMMON_STACK7, double check
 * IP5prom start up code. The IP5prom checks memory from 0 to GMCOMM_ADDR
 * and from GMCOMM_ADDR+GMCOMM_SIZE to SYMMON_STACK7. It then checks out
 * the GMCOMM area via gminit(). The rest of memory is checked later up to
 * 8Meg.
 */
#define MONITOR_STACK		(0xb0700000-4)
#define MONITOR_BSS		0xb0640000	/* Monitor text < 256K */
#define	MONITOR_TEXT		0xb0600000
#define PROM_STACK		MONITOR_STACK
#define	SYMMON_STACK7		0xb001b000
#define	SYMMON_STACK6		0xb001a000
#define	SYMMON_STACK5		0xb0019000
#define	SYMMON_STACK4		0xb0018000
#define	SYMMON_STACK3		0xb0017000
#define	SYMMON_STACK2		0xb0016000
#define	SYMMON_STACK1		0xb0015000
#define	SYMMON_STACK		0xb0014000
#define	SYMMON_STACKEND		SYMMON_STACK7
#define	SYMMON_BSSADDR		0xb0003000
#define	GMCOMM_ADDR		0xb0001000
#define	MPCONF_ADDR		0xb0000500
#define	RESTART_ADDR		0xb0000400

/*
 * Size definitions
 */
#define GMCOMM_SIZE		8*1024
#define	SYMMON_PDASIZE		512	/* size per CPU */
#define	MONITOR_SIZE		256*1024 /* will grow to be 256K */	

#endif /* __SYS_IP5ADDRS_H__ */
#endif /* IP5 */
